@@ -192,6 +192,8 @@
 #include "token_info-5.21.9.h"
 #elif PERL_VERSION == 22 && PERL_SUBVERSION == 0
 #include "token_info-5.22.0.h"
+#elif PERL_VERSION == 22 && PERL_SUBVERSION == 1
+#include "token_info-5.22.0.h"
 #elif PERL_VERSION == 22
 #include "token_info-5.22.0.h"
 #elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
@@ -200,7 +202,15 @@
 #include "token_info-5.23.0.h"
 #elif PERL_VERSION == 23 && PERL_SUBVERSION == 2
 #include "token_info-5.23.0.h"
-#elif PERL_VERSION > 23 || (PERL_VERSION == 23 && PERL_SUBVERSION > 2)
+#elif PERL_VERSION == 23 && PERL_SUBVERSION == 3
+#include "token_info-5.23.0.h"
+#elif PERL_VERSION == 23 && PERL_SUBVERSION == 4
+#include "token_info-5.23.4.h"
+#elif PERL_VERSION == 23 && PERL_SUBVERSION == 5
+#include "token_info-5.23.4.h"
+#elif PERL_VERSION == 23 && PERL_SUBVERSION == 6
+#include "token_info-5.23.4.h"
+#elif PERL_VERSION > 23 || (PERL_VERSION == 23 && PERL_SUBVERSION > 6)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
